@@ -8,15 +8,15 @@ from ..base import BaseTransformer
 class BaseEndogTransformer(BaseTransformer, metaclass=abc.ABCMeta):
     """A base class for endogenous array transformers"""
 
-    def _check_y_exog(self, y, exog):
+    def _check_y_X(self, y, X):
         """Check the endog and exog arrays"""
-        y, exog = super(BaseEndogTransformer, self)._check_y_exog(y, exog)
+        y, X = super(BaseEndogTransformer, self)._check_y_X(y, X)
         if y is None:
             raise ValueError("y must be non-None for endogenous transformers")
-        return y, exog
+        return y, X
 
     @abc.abstractmethod
-    def inverse_transform(self, y, exogenous=None):
+    def inverse_transform(self, y, X=None, **kwargs):  # TODO: remove kwargs
         """Inverse transform a transformed array
 
         Inverse the transformation on the transformed array.
@@ -26,7 +26,7 @@ class BaseEndogTransformer(BaseTransformer, metaclass=abc.ABCMeta):
         y : array-like or None, shape=(n_samples,)
             The transformed endogenous (time-series) array.
 
-        exogenous : array-like or None, shape=(n_samples, n_features), optional
+        X : array-like or None, shape=(n_samples, n_features), optional
             The exogenous array of additional covariates. Not used for
             endogenous transformers. Default is None, and non-None values will
             serve as pass-through arrays.
@@ -36,6 +36,6 @@ class BaseEndogTransformer(BaseTransformer, metaclass=abc.ABCMeta):
         y : array-like or None
             The inverse-transformed y array
 
-        exogenous : array-like or None
+        X : array-like or None
             The inverse-transformed exogenous array
         """
